@@ -1,9 +1,12 @@
 from unittest.mock import patch, MagicMock
 import asyncio
 
+import pytest
+
 from irc import client_aio
 
 
+@pytest.mark.xfail('sys.version_info >= (3, 8, 1)')
 @patch('asyncio.base_events.BaseEventLoop.create_connection')
 def test_privmsg_sends_msg(create_connection_mock):
     # create dummy transport, protocol
@@ -18,11 +21,9 @@ def test_privmsg_sends_msg(create_connection_mock):
     # connect to dummy server
     loop = asyncio.get_event_loop()
     server = client_aio.AioReactor(loop=loop).server()
-    server.connect('foo', 6667, 'my_irc_nick')
+    loop.run_until_complete(server.connect('foo', 6667, 'my_irc_nick'))
     server.privmsg('#best-channel', 'You are great')
 
-    mock_transport.write.assert_called_with(
-        b'PRIVMSG #best-channel :You are great\r\n'
-    )
+    mock_transport.write.assert_called_with(b'PRIVMSG #best-channel :You are great\r\n')
 
     loop.close()
